"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const hypernet_core_1 = require("@hypernetlabs/hypernet-core");
const rxjs_1 = require("rxjs");
const utils_1 = require("@hypernetlabs/utils");
class HypernetIFrameProxy extends utils_1.ParentProxy {
    constructor(element, iframeUrl) {
        super(element, iframeUrl);
        this.coreInitialized = false;
        this.isInControl = false;
        this._handshakePromise = null;
        this.onControlClaimed = new rxjs_1.Subject();
        this.onControlYielded = new rxjs_1.Subject();
        this.onPushPaymentProposed = new rxjs_1.Subject();
        this.onPullPaymentProposed = new rxjs_1.Subject();
        this.onPushPaymentReceived = new rxjs_1.Subject();
        this.onPullPaymentApproved = new rxjs_1.Subject();
        this.onPushPaymentUpdated = new rxjs_1.Subject();
        this.onPullPaymentUpdated = new rxjs_1.Subject();
        this.onBalancesChanged = new rxjs_1.Subject();
        this.onMerchantAuthorized = new rxjs_1.Subject();
        this.onAuthorizedMerchantUpdated = new rxjs_1.Subject();
        this.onAuthorizedMerchantActivationFailed = new rxjs_1.Subject();
        this.onMerchantIFrameDisplayRequested = new rxjs_1.Subject();
        this.onMerchantIFrameCloseRequested = new rxjs_1.Subject();
        this.onMerchantIFrameClosed = new rxjs_1.Subject();
        this.onMerchantIFrameDisplayed = new rxjs_1.Subject();
        // Initialize the promise that we'll use to monitor the core
        // initialization status. The iframe will emit an event "initialized"
        // once the core is initialized, we'll use that to resolve this promise.
        this.waitInitializedPromise = new Promise((resolve) => {
            this._handshakePromise = this.handshake.then((child) => {
                // Subscribe to the message streams from the iframe,
                // and convert them back to RXJS Subjects.
                child.on("onControlClaimed", (data) => {
                    this.isInControl = true;
                    this.onControlClaimed.next(data);
                });
                child.on("onControlYielded", (data) => {
                    this.isInControl = false;
                    this.onControlYielded.next(data);
                });
                child.on("onPushPaymentProposed", (data) => {
                    this.onPushPaymentProposed.next(data);
                });
                child.on("onPullPaymentProposed", (data) => {
                    this.onPullPaymentProposed.next(data);
                });
                child.on("onPushPaymentReceived", (data) => {
                    this.onPushPaymentReceived.next(data);
                });
                child.on("onPullPaymentApproved", (data) => {
                    this.onPullPaymentApproved.next(data);
                });
                child.on("onPushPaymentUpdated", (data) => {
                    this.onPushPaymentUpdated.next(data);
                });
                child.on("onPullPaymentUpdated", (data) => {
                    this.onPullPaymentUpdated.next(data);
                });
                child.on("onBalancesChanged", (data) => {
                    this.onBalancesChanged.next(data);
                });
                child.on("onMerchantAuthorized", (data) => {
                    this.onMerchantAuthorized.next(data);
                });
                child.on("onAuthorizedMerchantUpdated", (data) => {
                    this.onAuthorizedMerchantUpdated.next(data);
                });
                child.on("onAuthorizedMerchantActivationFailed", (data) => {
                    this.onAuthorizedMerchantActivationFailed.next(data);
                });
                // Setup a listener for the "initialized" event.
                child.on("initialized", () => {
                    // Resolve waitInitialized
                    resolve();
                    // And mark us as initialized
                    this.coreInitialized = true;
                });
                child.on("onMerchantIFrameDisplayRequested", (data) => {
                    // Remove it later, this is just for the purpose of the demo, we dont need to show merchant-iframe modal if the core modal is opened
                    const coreModal = document.getElementById("__hypernet-protocol-modal-root__");
                    if (coreModal)
                        return;
                    child.frame.style.display = "block";
                    if (element) {
                        element.style.display = "block";
                    }
                });
                child.on("onMerchantIFrameCloseRequested", (data) => {
                    child.frame.style.display = "none";
                    if (element) {
                        element.style.display = "none";
                    }
                });
                this.onMerchantIFrameClosed.subscribe((data) => {
                    child.frame.style.display = "none";
                    if (element) {
                        element.style.display = "none";
                    }
                    this._createCall("onMerchantIFrameClosed", data);
                });
                this.onMerchantIFrameDisplayed.subscribe((data) => {
                    child.frame.style.display = "block";
                    if (element) {
                        element.style.display = "block";
                    }
                    this._createCall("onMerchantIFrameDisplayed", data);
                });
            });
        });
    }
    initialized() {
        // If the child is not initialized, there is no way the core can be.
        if (this.child == null) {
            return hypernet_core_1.ok(false);
        }
        // Return the current known status of coreInitialized. We request this
        // information as soon as the child is up.
        return hypernet_core_1.ok(this.coreInitialized);
    }
    waitInitialized() {
        return this.activate().andThen(() => {
            return this._createCall("waitInitialized", null);
        });
    }
    inControl() {
        // If the child is not initialized, there is no way the core can be.
        if (this.child == null) {
            return hypernet_core_1.ok(false);
        }
        // Return the current known status of inControl.
        return hypernet_core_1.ok(this.isInControl);
    }
    getEthereumAccounts() {
        return this._createCall("getEthereumAccounts", null);
    }
    initialize(account) {
        return this._createCall("initialize", account);
    }
    getPublicIdentifier() {
        return this._createCall("getPublicIdentifier", null);
    }
    depositFunds(assetAddress, amount) {
        return this._createCall("depositFunds", { assetAddress, amount: amount.toString() });
    }
    withdrawFunds(assetAddress, amount, destinationAddress) {
        return this._createCall("withdrawFunds", { assetAddress, amount: amount.toString(), destinationAddress });
    }
    getBalances() {
        return this._createCall("getBalances", null);
    }
    getLinks() {
        return this._createCall("getLinks", null);
    }
    getActiveLinks() {
        return this._createCall("getActiveLinks", null);
    }
    getLinkByCounterparty(counterPartyAccount) {
        throw new Error("Unimplemented");
    }
    sendFunds(counterPartyAccount, amount, expirationDate, requiredStake, paymentToken, merchantUrl) {
        return this._createCall("sendFunds", {
            counterPartyAccount,
            amount,
            expirationDate,
            requiredStake,
            paymentToken,
            merchantUrl,
        });
    }
    authorizeFunds(counterPartyAccount, totalAuthorized, expirationDate, deltaAmount, deltaTime, requiredStake, paymentToken, merchantUrl) {
        return this._createCall("authorizeFunds", {
            counterPartyAccount,
            totalAuthorized,
            expirationDate,
            deltaAmount,
            deltaTime,
            requiredStake,
            paymentToken,
            merchantUrl,
        });
    }
    acceptOffers(paymentIds) {
        return this._createCall("acceptFunds", paymentIds);
    }
    pullFunds(paymentId, amount) {
        return this._createCall("pullFunds", {
            paymentId,
            amount: amount.toString(),
        });
    }
    finalizePullPayment(paymentId, finalAmount) {
        throw new Error("Unimplemented");
    }
    finalizePushPayment(paymentId) {
        throw new Error("Unimplemented");
    }
    initiateDispute(paymentId) {
        return this._createCall("initiateDispute", paymentId);
    }
    mintTestToken(amount) {
        return this._createCall("mintTestToken", amount.toString());
    }
    authorizeMerchant(merchantUrl) {
        return this._createCall("authorizeMerchant", merchantUrl);
    }
    getAuthorizedMerchants() {
        return this._createCall("getAuthorizedMerchants", null);
    }
}
exports.default = HypernetIFrameProxy;
//# sourceMappingURL=HypernetIFrameProxy.js.map